[pyfr] 64/88: Increase the alignment for the OpenMP backend to 64 bytes.

Ghislain Vaillant ghisvail-guest at moszumanska.debian.org
Wed Nov 16 12:05:30 UTC 2016


This is an automated email from the git hooks/post-receive script.

ghisvail-guest pushed a commit to branch master
in repository pyfr.

commit 46f2d9d805d984e2d7b21b189c92a0e7c86e4df8
Author: Freddie Witherden <freddie at witherden.org>
Date:   Wed Jul 20 20:54:01 2016 -0700

    Increase the alignment for the OpenMP backend to 64 bytes.
---
 pyfr/backends/openmp/base.py | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/pyfr/backends/openmp/base.py b/pyfr/backends/openmp/base.py
index 6c6a6e5..93bccb2 100644
--- a/pyfr/backends/openmp/base.py
+++ b/pyfr/backends/openmp/base.py
@@ -11,8 +11,8 @@ class OpenMPBackend(BaseBackend):
     def __init__(self, cfg):
         super().__init__(cfg)
 
-        # Take the alignment requirement to be 32-bytes
-        self.alignb = 32
+        # Take the alignment requirement to be 64-bytes
+        self.alignb = 64
 
         # Compute the SoA size
         self.soasz = self.alignb // np.dtype(self.fpdtype).itemsize

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/debian-science/packages/pyfr.git



More information about the debian-science-commits mailing list